{% extends "admin_layout.jinja2" %}
{% block body %}
<style>
    html {
        height: 100%;
    }

    body {
        padding: 0;
        margin: 0;
        font-family: sans-serif;
        display: flex;
        justify-content: center;
        align-items: center;
        min-height: 100%;
    }

    #login-form {
        padding: 25px;
        margin: auto;
        background-color: #fafafa;
        box-shadow: 10px 10px 10px rgba(0, 0, 0, 0.1);
        border: 1px solid #eaeaea;
    }

</style>

<div id="login-form">

    <h1>Channelstream</h1>

    <form action="{{ request.route_url('admin_action', action="sign_in") }}" method="post">
        <input type="text" name="username" placeholder="Username">
        <input type="password" name="password" placeholder="Password">
        <input type="submit" value="Sign In">
    </form>

</div>
{% endblock %}
