SHARED_DEFAULTS = {
    "secret": "secret",
    "admin_user": "admin",
    "admin_secret": "admin_secret",
    "cookie_secret": "",
    "gc_conns_after": 30,
    "gc_channels_after": 3600 * 72,
    "wake_connections_after": 5,
    "allow_posting_from": ["127.0.0.1"],
    "port": 8000,
    "host": "0.0.0.0",
    "debug": False,
    "log_level": "INFO",
    "demo": False,
    "allow_cors": "",
    "validate_requests": True,
    "enforce_https": False,
    "http_scheme": "",
}

CONFIGURABLE_PARAMS = (
    "debug",
    "log_level",
    "port",
    "host",
    "secret",
    "admin_user",
    "admin_secret",
    "cookie_secret",
    "allow_posting_from",
    "allow_cors",
    "validate_requests",
    "enforce_https",
    "http_scheme",
)
