<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <title>Channelstream Admin</title>
    <base href="{{ request.route_url('index')[:-1] }}"/>

    <script>
        var AppConf = {
            urls: {
                baseUrl: '{{ request.route_url('index')[:-1] }}',
                jsonUrl: '{{ request.route_url('admin_json') }}'
            }
        }

        window.process = {
            env: {
                NODE_ENV: 'production'
            }
        };

    </script>
    <script src="{{ request.static_url('channelstream:static/webcomponentsjs/custom-elements-es5-adapter.js') }}"></script>
    <script src="{{ request.static_url('channelstream:static/webcomponentsjs/webcomponents-loader.js') }}"></script>
    <script type="module">
        import '{{ request.static_url('channelstream:static/channelstream-admin.js') }}';
    </script>
    <script nomodule src="{{ request.static_url('channelstream:static/@babel/polyfill/browser.js') }}"></script>
    <script nomodule src="{{ request.static_url('channelstream:static/channelstream-admin.es5.js') }}"></script>

</head>
<body>

{% block body %}
{% endblock %}

</body>
</html>
